djangocms-grid
==============

A Multi Column Plugin for django CMS, that uses a common grid system.


Installation
------------

This plugin requires `django CMS` 2.4 or higher to be properly installed.

* In your projects `virtualenv`_, run ``pip install djangocms-grid``.
* Add ``'djangocms_grid'`` to your ``INSTALLED_APPS`` setting.
* Run ``manage.py migrate djangocms_grid``.


Usage
-----

